==> tibet-5.3.6.tgz: package/src/svg/svg_ConditionalProcessingModuleNodes.js <==
//  ========================================================================
/**
 * @copyright Copyright (C) 1999 Technical Pursuit Inc. (TPI) All Rights
 *     Reserved. Patents Pending, Technical Pursuit Inc. Licensed under the
 *     OSI-approved Reciprocal Public License (RPL) Version 1.5. See the RPL
 *     for your rights and responsibilities. Contact TPI to purchase optional
 *     privacy waivers if you must keep your TIBET-based source code private.
 */
//  ------------------------------------------------------------------------

//  ========================================================================
//  TP.svg.switch
//  ========================================================================

/**
 * @type {TP.svg.switch}
 */

//  ------------------------------------------------------------------------

TP.dom.UIElementNode.defineSubtype('svg:switch');

//  Some JS parsers are stricter than others about reserved words, so we
//  have to use the 'slot name' version of the type name.
TP.svg.switch.addTraits(TP.svg.Element);

TP.svg.switch.Type.resolveTrait('cmdRunContent', TP.svg.Element);
TP.svg.switch.Inst.resolveTrait('isReadyToRender', TP.svg.Element);

//  ------------------------------------------------------------------------
//  Type Attributes
//  ------------------------------------------------------------------------

TP.svg.switch.Type.set('uriAttrs',
        TP.ac('clip-path', 'cursor', 'filter', 'mask'));

//  ------------------------------------------------------------------------
//  end
//  ========================================================================

==> tibet-6.0.1.tgz: package/src/svg/svg_ConditionalProcessingModuleNodes.js <==
//  ========================================================================
/**
 * @copyright Copyright (C) 1999 Technical Pursuit Inc. (TPI) All Rights
 *     Reserved. Patents Pending, Technical Pursuit Inc. Licensed under the
 *     OSI-approved Reciprocal Public License (RPL) Version 1.5. See the RPL
 *     for your rights and responsibilities. Contact TPI to purchase optional
 *     privacy waivers if you must keep your TIBET-based source code private.
 */
//  ------------------------------------------------------------------------

//  ========================================================================
//  TP.svg.switch
//  ========================================================================

/**
 * @type {TP.svg.switch}
 */

//  ------------------------------------------------------------------------

TP.dom.UIElementNode.defineSubtype('svg:switch');

//  Some JS parsers are stricter than others about reserved words, so we
//  have to use the 'slot name' version of the type name.
TP.svg.switch.addTraitTypes(TP.svg.Element);

TP.svg.switch.Type.resolveTrait('cmdRunContent', TP.svg.Element);
TP.svg.switch.Inst.resolveTrait('isReadyToRender', TP.svg.Element);

//  ------------------------------------------------------------------------
//  Type Attributes
//  ------------------------------------------------------------------------

TP.svg.switch.Type.set('uriAttrs',
        TP.ac('clip-path', 'cursor', 'filter', 'mask'));

//  ------------------------------------------------------------------------
//  end
//  ========================================================================
